@@ -12,7 +12,7 @@ String::License::Naming::SPDX - licenses as named by SPDX
 
 =head1 VERSION
 
-Version v0.0.7
+Version v0.0.8
 
 =head1 SYNOPSIS
 
@@ -45,16 +45,16 @@ or as fallback by an internal name.
 
 =cut
 
-package String::License::Naming::SPDX v0.0.7;
+package String::License::Naming::SPDX v0.0.8;
 
-use Carp            qw(croak);
-use Log::Any        ();
-use List::SomeUtils qw(uniq);
+use Carp       qw(croak);
+use Log::Any   ();
+use List::Util qw(uniq);
 use Regexp::Pattern::License 3.4.0;
 
 use namespace::clean;
 
-class String::License::Naming::SPDX :isa(String::License::Naming);
+class String::License::Naming::SPDX : isa(String::License::Naming);
 
 field $log;
 
